pub enum CheckpointParityError {
Io(Error),
Json(Error),
SafeTensors(SafeTensorError),
Observation(ObservationError),
Parity(ParityError),
InvalidArtifact {
path: PathBuf,
message: String,
},
}Expand description
Invalid checkpoint evidence or parity policy.
Variants
Io(Error)
Artifact I/O failed.
Json(Error)
Artifact JSON is invalid.
SafeTensors(SafeTensorError)
SafeTensors data is invalid or incomplete.
Observation(ObservationError)
Portable observation data is invalid.
Parity(ParityError)
General comparison failed before a report could be produced.
InvalidArtifact
A required checkpoint artifact field is absent or malformed.