pub struct ContinuationFixtureLimits {
pub host_bytes: u64,
pub growth_bytes: u64,
pub max_predictions: u64,
pub capture: Option<CaptureLimits>,
}Expand description
Known fixture storage bounds and explicitly admitted child limits.
Fields
host_bytes: u64Controller/host storage through the fixture’s complete continuation.
growth_bytes: u64Additional native and host growth through the absolute prediction limit.
max_predictions: u64Absolute prediction limit, at least eight for this scenario.
capture: Option<CaptureLimits>Explicit child capture limits, including inherited consumption.